Crate aranya_daemon

Crate aranya_daemon 

The Daemon library.

This crate is an implementation detail for the aranya-daemon executable. It is permanently unstable and does NOT promise backward compatibility.

Modules

actions
Aranya graph actions/effects API.
aranya
This module provides the Client struct, which wraps an aranya_runtime::ClientState
config
Daemon configuration.
policy
This code is @generated by policy-ifgen. DO NOT EDIT.
sync
Aranya syncer used to send/receive graph commands to other peers.
vm_policy

Macros

find_effect
Find the first effect matching a given pattern.

Structs

AranyaStore
The Aranya keystore.
Daemon
The daemon itself.
DaemonHandle
Handle for the spawned daemon.